@@ -4,7 +4,9 @@ use warnings;
 
 require 5.008_001;
 
-our $VERSION = '0.39';
+# ABSTRACT: SAML2 bindings and protocol implementation
+
+our $VERSION = '0.41';
 $VERSION = eval {$VERSION};
 
 
@@ -35,14 +37,17 @@ __END__
 
 =head1 NAME
 
-Net::SAML2
+Net::SAML2 - SAML2 bindings and protocol implementation
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
+  See TUTORIAL.md for implementation documentation and
+  t/12-full-client.t for a pseudo implementation following the tutorial
+
   # generate a redirect off to the IdP:
 
         my $idp = Net::SAML2::IdP->new($IDP);
@@ -125,6 +130,8 @@ Identity Providers (IdPs).  It has been tested against:
 
 =item Auth0 (requires Net::SAML2 >=0.39)
 
+=item PingIdentity
+
 =back
 
 =head1 NAME
