@@ -3,6 +3,10 @@ use Moose;
 use MooseX::Types::URI qw/ Uri /;
 use Net::SAML2::XML::Util qw/ no_comments /;
 
+our $VERSION = '0.41';
+
+# ABSTRACT: Net::SAML2::Binding::Artifact - SOAP binding for SAML
+
 
 use Net::SAML2::XML::Sig;
 use XML::LibXML;
@@ -162,11 +166,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::Binding::SOAP
+Net::SAML2::Binding::SOAP - Net::SAML2::Binding::Artifact - SOAP binding for SAML
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
