@@ -2,6 +2,10 @@ package Net::SAML2::IdP;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 
+our $VERSION = '0.41';
+
+# ABSTRACT: Net::SAML2::IdP - SAML Identity Provider object
+
 
 use Crypt::OpenSSL::Verify;
 use Crypt::OpenSSL::X509;
@@ -227,15 +231,24 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::IdP
+Net::SAML2::IdP - Net::SAML2::IdP - SAML Identity Provider object
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
-  my $idp = Net::SAML2::IdP->new_from_url( url => $url, cacert => $cacert );
+  my $idp = Net::SAML2::IdP->new_from_url(
+        url => $url,
+        cacert => $cacert,
+        ssl_opts =>         # Optional options supported by LWP::Protocol::https
+            {
+                SSL_ca_file     => '/your/directory/cacert.pem',
+                SSL_ca_path     => '/etc/ssl/certs',
+                verify_hostname => 1,
+            }
+        );
   my $sso_url = $idp->sso_url('urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect');
 
 =head1 NAME
@@ -254,11 +267,11 @@ Constructor
 
 =back
 
-=head2 new_from_url( url => $url, cacert => $cacert )
+=head2 new_from_url( url => $url, cacert => $cacert, ssl_opts => {} )
 
 Create an IdP object by retrieving the metadata at the given URL.
 
-Dies if the metadata can't be retrieved.
+Dies if the metadata can't be retrieved with reason.
 
 =head2 new_from_xml( xml => $xml, cacert => $cacert )
 
