@@ -4,6 +4,10 @@ use MooseX::Types::URI qw/ Uri /;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
+our $VERSION = '0.41';
+
+# ABSTRACT: Net::SAML2::Protocol::ArtifactResolve - ArtifactResolve protocol class
+
 
 
 has 'issuer'      => (isa => 'Str', is => 'ro', required => 1);
@@ -49,11 +53,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::Protocol::ArtifactResolve
+Net::SAML2::Protocol::ArtifactResolve - Net::SAML2::Protocol::ArtifactResolve - ArtifactResolve protocol class
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
