@@ -10,6 +10,10 @@ use XML::LibXML;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
+our $VERSION = '0.41';
+
+# ABSTRACT: Net::SAML2::Protocol::Assertion - SAML2 assertion object
+
 
 has 'attributes'        => (isa => 'HashRef[ArrayRef]', is => 'ro', required => 1);
 has 'session'           => (isa => 'Str',               is => 'ro', required => 1);
@@ -113,11 +117,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::Protocol::Assertion
+Net::SAML2::Protocol::Assertion - Net::SAML2::Protocol::Assertion - SAML2 assertion object
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
