@@ -5,6 +5,10 @@ use Net::SAML2::XML::Util qw/ no_comments /;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
+# ABSTRACT: SAML2 LogoutResponse Protocol object
+
+our $VERSION = '0.41';
+
 
 has 'status'      => (isa => 'Str', is => 'ro', required => 1);
 has 'substatus'   => (isa => 'Str', is => 'ro', required => 0);
@@ -81,11 +85,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::Protocol::LogoutResponse
+Net::SAML2::Protocol::LogoutResponse - SAML2 LogoutResponse Protocol object
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
