@@ -2,6 +2,10 @@ package Net::SAML2::SP;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 
+our $VERSION = '0.41';
+
+# ABSTRACT: Net::SAML2::SP - SAML Service Provider object
+
 
 use Crypt::OpenSSL::X509;
 use XML::Generator;
@@ -197,6 +201,11 @@ sub metadata {
                 { Binding => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect',
                   Location  => $self->url . '/saml/sls-redirect-response' },
             ),
+            $x->SingleLogoutService(
+                $md,
+                { Binding => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST',
+                  Location  => $self->url . '/saml/sls-post-response' },
+            ),
             $x->AssertionConsumerService(
                 $md,
                 { Binding => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST',
@@ -259,11 +268,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::SP
+Net::SAML2::SP - Net::SAML2::SP - SAML Service Provider object
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
